==> ape_1.8-3.tar.gz: ape/data/xenarthra.R <==
"xenarthra" <- 
structure(list(edge = structure(c("-1", "-1", "-2", "-2", "-1", 
"-3", "-4", "-5", "-6", "-7", "-7", "-6", "-8", "-9", "-9", "-10", 
"-10", "-8", "-11", "-11", "-12", "-12", "-5", "-13", "-14", 
"-14", "-15", "-15", "-13", "-16", "-16", "-4", "-17", "-18", 
"-18", "-19", "-19", "-17", "-20", "-20", "-21", "-21", "-22", 
"-22", "-3", "-23", "-24", "-24", "-25", "-25", "-26", "-26", 
"-27", "-27", "-28", "-29", "-29", "-30", "-30", "-28", "-31", 
"-31", "-23", "-32", "-33", "-33", "-32", "-34", "-35", "-36", 
"-37", "-38", "-38", "-37", "-39", "-39", "-36", "-40", "-40", 
"-41", "-41", "-35", "-42", "-43", "-43", "-42", "-44", "-44", 
"-45", "-45", "-46", "-46", "-47", "-47", "-34", "-48", "-48", 
"1", "-2", "2", "3", "-3", "-4", "-5", "-6", "-7", "4", "5", 
"-8", "-9", "6", "-10", "7", "8", "-11", "9", "-12", "10", "11", 
"-13", "-14", "12", "-15", "13", "14", "-16", "15", "16", "-17", 
"-18", "17", "-19", "18", "19", "-20", "20", "-21", "21", "-22", 
"22", "23", "-23", "-24", "24", "-25", "25", "-26", "26", "-27", 
"27", "-28", "-29", "28", "-30", "29", "30", "-31", "31", "32", 
"-32", "-33", "33", "34", "-34", "-35", "-36", "-37", "-38", 
"35", "36", "-39", "37", "38", "-40", "39", "-41", "40", "41", 
"-42", "-43", "42", "43", "-44", "44", "-45", "45", "-46", "46", 
"-47", "47", "48", "-48", "49", "50"), .Dim = c(97, 2)), edge.length = c(0.109894, 
0.022173, 0.066834, 0.047474, 0.427827, 0.002024, 0.025857, 0.022981, 
0.026731, 0.007126, 0.008411, 0.006233, 0.017379, 0.002957, 0.001106, 
0.002583, 0.003687, 0.005152, 0.012123, 0.000671, 0.011783, 0.008738, 
0.008776, 0.011882, 0.035474, 0.038071, 0.012415, 0.012484, 0.025252, 
0.021598, 0.015425, 0.029149, 0.013247, 0.033688, 0.003945, 0.047081, 
0.123258, 0.004856, 0.082597, 0.002941, 0.156433, 0.006792, 0.097117, 
0.220728, 0.009689, 0.00691, 0.12952, 0.00221, 0.086326, 0.000742, 
0.06454, 0.00375, 0.140251, 0.012014, 0.006192, 0.266772, 0.204941, 
0.070565, 0.056994, 0.041168, 0.058614, 0.062632, 0.013307, 0.015539, 
0.112732, 0.168348, 0.003898, 0.00109, 0.014771, 0.001936, 0.050427, 
0.017972, 0.038131, 0.007296, 0.070184, 0.060133, 0.014944, 0.182596, 
0.010519, 0.055868, 0.040506, 0.000379, 0.015614, 0.035851, 0.045494, 
0.024393, 0.059475, 0.005829, 0.081795, 0.00852, 0.09217, 0.003101, 
0.051699, 0.038765, 0.006122, 0.082358, 0.082157), tip.label = c("Didelphis", 
"Macropus", "Vombatus", "Dasypus_no", "Dasypus_ka", "Zaedyus", 
"Chaetophractus", "Euphractus", "Priodontes", "Tolypeutes", "Cabassous", 
"Cyclopes", "Myrmecophaga", "Tamandua", "Bradypus", "Choloepus", 
"Dugong", "Elephas", "Procavia", "Orycteropus", "Macroscelides", 
"Amblysomus", "Echinops", "Tupaia", "Homo", "Cynocephalus", "Lepus", 
"Hystrix", "Mus", "Rattus", "Glaucomys", "Aplodontia", "Scalopus", 
"Erinaceus", "Pteropus", "Cynopterus", "Megaderma", "Hipposideros", 
"Tonatia", "Myotis", "Tadarida", "Diceros", "Equus", "Lama", 
"Sus", "Bos", "Hippopotamus", "Physeter", "Manis", "Felis")), .Names = c("edge", 
"edge.length", "tip.label"), class = "phylo")

==> ape_2.2-4.tar.gz: ape/data/xenarthra.R <==
"xenarthra" <-
structure(list(edge = structure(c(51, 51, 52, 52, 51, 53, 54,
55, 56, 57, 57, 56, 58, 59, 59, 60, 60, 58, 61, 61, 62, 62, 55,
63, 64, 64, 65, 65, 63, 66, 66, 54, 67, 68, 68, 69, 69, 67, 70,
70, 71, 71, 72, 72, 53, 73, 74, 74, 75, 75, 76, 76, 77, 77, 78,
79, 79, 80, 80, 78, 81, 81, 73, 82, 83, 83, 82, 84, 85, 86, 87,
88, 88, 87, 89, 89, 86, 90, 90, 91, 91, 85, 92, 93, 93, 92, 94,
94, 95, 95, 96, 96, 97, 97, 84, 98, 98, 1, 52, 2, 3, 53, 54,
55, 56, 57, 4, 5, 58, 59, 6, 60, 7, 8, 61, 9, 62, 10, 11, 63,
64, 12, 65, 13, 14, 66, 15, 16, 67, 68, 17, 69, 18, 19, 70, 20,
71, 21, 72, 22, 23, 73, 74, 24, 75, 25, 76, 26, 77, 27, 78, 79,
28, 80, 29, 30, 81, 31, 32, 82, 83, 33, 34, 84, 85, 86, 87, 88,
35, 36, 89, 37, 38, 90, 39, 91, 40, 41, 92, 93, 42, 43, 94, 44,
95, 45, 96, 46, 97, 47, 48, 98, 49, 50), .Dim = c(97, 2)), edge.length = c(0.109894,
0.022173, 0.066834, 0.047474, 0.427827, 0.002024, 0.025857, 0.022981,
0.026731, 0.007126, 0.008411, 0.006233, 0.017379, 0.002957, 0.001106,
0.002583, 0.003687, 0.005152, 0.012123, 0.000671, 0.011783, 0.008738,
0.008776, 0.011882, 0.035474, 0.038071, 0.012415, 0.012484, 0.025252,
0.021598, 0.015425, 0.029149, 0.013247, 0.033688, 0.003945, 0.047081,
0.123258, 0.004856, 0.082597, 0.002941, 0.156433, 0.006792, 0.097117,
0.220728, 0.009689, 0.00691, 0.12952, 0.00221, 0.086326, 0.000742,
0.06454, 0.00375, 0.140251, 0.012014, 0.006192, 0.266772, 0.204941,
0.070565, 0.056994, 0.041168, 0.058614, 0.062632, 0.013307, 0.015539,
0.112732, 0.168348, 0.003898, 0.00109, 0.014771, 0.001936, 0.050427,
0.017972, 0.038131, 0.007296, 0.070184, 0.060133, 0.014944, 0.182596,
0.010519, 0.055868, 0.040506, 0.000379, 0.015614, 0.035851, 0.045494,
0.024393, 0.059475, 0.005829, 0.081795, 0.00852, 0.09217, 0.003101,
0.051699, 0.038765, 0.006122, 0.082358, 0.082157), tip.label = c("Didelphis",
"Macropus", "Vombatus", "Dasypus_no", "Dasypus_ka", "Zaedyus",
"Chaetophractus", "Euphractus", "Priodontes", "Tolypeutes", "Cabassous",
"Cyclopes", "Myrmecophaga", "Tamandua", "Bradypus", "Choloepus",
"Dugong", "Elephas", "Procavia", "Orycteropus", "Macroscelides",
"Amblysomus", "Echinops", "Tupaia", "Homo", "Cynocephalus", "Lepus",
"Hystrix", "Mus", "Rattus", "Glaucomys", "Aplodontia", "Scalopus",
"Erinaceus", "Pteropus", "Cynopterus", "Megaderma", "Hipposideros",
"Tonatia", "Myotis", "Tadarida", "Diceros", "Equus", "Lama",
"Sus", "Bos", "Hippopotamus", "Physeter", "Manis", "Felis"),
    Nnode = 48), .Names = c("edge", "edge.length", "tip.label",
"Nnode"), class = "phylo")
